@@ -1,15 +1,23 @@
 #!/bin/sh
 
-srcdir=${srcdir:-.}
+# This script setups new environment with debootstrap, installs necessary
+# packages with APT, downloads source package for hello, and builds the
+# binary package.
+#
+# It should work with any Debian-based system.
 
-test -d $srcdir/bin && export PATH=$srcdir/bin:$PATH
+srcdir=${srcdir:-.}
+abs_srcdir=${abs_srcdir:-`cd "$srcdir" 2>/dev/null && pwd -P`}
+
+test -d "$abs_srcdir/bin" && export PATH="$abs_srcdir/bin:$PATH"
 
 run () {
-    HOME=/root fakechroot /usr/sbin/chroot $destdir "$@"
+    HOME=/root fakechroot chroot $destdir "$@"
 }
 
 vendor=${VENDOR:-`lsb_release -s -i`}
 release=${RELEASE:-`lsb_release -s -c`}
+variant=$VARIANT
 type=`dpkg-architecture -qDEB_HOST_GNU_TYPE`
 systype=${type#*-}
 arch=${ARCH:-`dpkg-architecture -t$(arch)-$systype -qDEB_HOST_ARCH 2>/dev/null`}
@@ -18,18 +26,16 @@ if [ $# -gt 0 ]; then
     destdir=$1
     shift
 else
-    destdir=`pwd -P`/testtree
+    destdir="$abs_srcdir/testtree"
 fi
 
-tarball=$vendor-$release-$arch.debs.tgz
+tarball=$vendor-$release${variant:+-$variant}-$arch.debs.tgz
 
-export FAKECHROOT_EXCLUDE_PATH=${FAKECHROOT_EXCLUDE_PATH:-/dev:/proc:/sys}
-export FAKECHROOT_CMD_SUBST=/sbin/insserv=/bin/true:/sbin/ldconfig=/bin/true:/usr/bin/ischroot=/bin/true:/usr/bin/ldd=/usr/bin/ldd.fakechroot:/usr/bin/mkfifo=/bin/true
 export FAKECHROOT_AF_UNIX_PATH=/tmp
 
-debootstrap_opts="--arch=$arch --variant=fakechroot"
+debootstrap_opts="--arch=$arch ${variant:+--variant=$variant}"
 if [ ! -f $tarball ]; then
-    FAKECHROOT=true fakeroot /usr/sbin/debootstrap --download-only --make-tarball=$tarball --include=build-essential,devscripts,fakeroot,gnupg $debootstrap_opts $release $destdir "$@"
+    FAKECHROOT=true fakeroot debootstrap --download-only --make-tarball=$tarball --include=build-essential,devscripts,fakeroot,gnupg $debootstrap_opts $release $destdir "$@"
 fi
 
 rm -rf $destdir
@@ -39,7 +45,7 @@ if ! which chroot >/dev/null; then
     export PATH
 fi
 
-fakechroot fakeroot /usr/sbin/debootstrap --unpack-tarball="`pwd`/$tarball" $debootstrap_opts $release $destdir
+fakechroot fakeroot debootstrap --unpack-tarball="`pwd`/$tarball" $debootstrap_opts $release $destdir
 
 HOME=/root fakechroot fakeroot /usr/sbin/chroot $destdir apt-get --force-yes -y --no-install-recommends install build-essential devscripts fakeroot gnupg
 
